// XpiInstaller
// By Pike (Heavily inspired by code from Henrik Gemal and Stephen Clavering)

var XpiInstaller = {

	// --- Editable items begin ---
	extFullName: 'Cooliris Previews', // The name displayed to the user (don't include the version)
	extShortName: 'cooliris', // The leafname of the JAR file (without the .jar part)
	extVersion: '2.1',
	extAuthor: 'Cooliris Inc, www.cooliris.com',
	extLocaleNames: ['zh-TW'],
	extSkinNames: ['classic'], // e.g. ['classic', 'modern']
	extPostInstallMessage: '\IЭsҰ Firefox ,HKwˡC', // Set to null for no post-install message
	// --- Editable items end ---

	profileInstall: true,
	silentInstall: true,

	install: function()
	{
		var jarName = this.extShortName + '.jar';
		var mainDir = getFolder("Profile", "extensions/" + "{CE6E6E3B-84DD-4cac-9F63-8D2AE4F30A4B}");

		var profileDir = Install.getFolder(mainDir, 'chrome');

		// Parse HTTP arguments
		this.parseArguments();

		// Check if extension is already installed in profile
		if (File.exists(Install.getFolder(profileDir, jarName)))
		{
			if (!this.silentInstall)
			{
				Install.alert('s ' + this.extFullName + '  ' + this.extVersion + 'C');
			}
			this.profileInstall = true;
		}
		else if (!this.silentInstall)
		{
			// Ask user for install location, profile or browser dir?
			this.profileInstall = Install.confirm('N ' + this.extFullName + ' ' + this.extVersion + ' w˨zӤH(Profile)ؿ (OK) Ψzsؿ (Cancel)?');
		}

		// Init install
		var dispName = this.extFullName + ' ' + this.extVersion;
		var regName = '/' + this.extAuthor + '/' + this.extShortName;
		Install.initInstall(dispName, regName, this.extVersion);

		// Find directory to install into
		var installPath;
		if (this.profileInstall) installPath = profileDir;
		else installPath = Install.getFolder('chrome');

		// Add JAR file
		Install.addFile(null, 'chrome/' + jarName, installPath, null);

		// Register chrome
		var jarPath = Install.getFolder(installPath, jarName);
		var installType = this.profileInstall ? Install.PROFILE_CHROME : Install.DELAYED_CHROME;

		// Register content
		Install.registerChrome(Install.CONTENT | installType, jarPath, 'content/' + this.extShortName + '/');

		// Register locales
		for (var locale in this.extLocaleNames)
		{
			var regPath = 'locale/' + this.extShortName + '/' + this.extLocaleNames[locale] + '/';
			Install.registerChrome(Install.LOCALE | installType, jarPath, regPath);
		}

		// Register skins
		for (var skin in this.extSkinNames)
		{
			var regPath = 'skin/' + this.extSkinNames[skin] + '/' + this.extShortName + '/';
			Install.registerChrome(Install.SKIN | installType, jarPath, regPath);
		}

		// Perform install
		var err = Install.performInstall();
		if (err == Install.SUCCESS || err == Install.REBOOT_NEEDED)
		{
			if (!this.silentInstall && this.extPostInstallMessage)
			{
				Install.alert(this.extPostInstallMessage);
			}
		}
		else
		{
			this.handleError(err);
			return;
		}
	},

	parseArguments: function()
	{
		// Can't use string handling in install, so use if statement instead
		var args = Install.arguments;
		if (args == 'p=0')
		{
			this.profileInstall = false;
			this.silentInstall = true;
		}
		else if (args == 'p=1')
		{
			this.profileInstall = true;
			this.silentInstall = true;
		}
	},

	handleError: function(err)
	{
		if (!this.silentInstall)
		{
			Install.alert('~: Lkw ' + this.extFullName + ' ' + this.extVersion + ' (~N: ' + err + ')');
		}
		Install.cancelInstall(err);
	}
};

XpiInstaller.install();
